pub struct CachedArgs {
pub duration: Duration,
pub key: CachedKeyArgs,
pub no_cached_output: bool,
pub exit_code: bool,
pub verbose: bool,
pub cmd: CommandArgs,
}Fields
duration: DurationDuration after which the cache should be invalidated, e.g. “30 min” or “1 day -1 hour”.
key: CachedKeyArgsno_cached_output: boolWhen loading from cache, do not show the previous output.
exit_code: boolUse exit code 0 if the command is cached, and exit code 255 if it ran successfully.
verbose: boolPrint extra information, e.g. whether the command was run or not.
cmd: CommandArgsImplementations
Sourceimpl CachedArgs
impl CachedArgs
pub fn any_explicit_key(&self) -> bool